@@ -35,6 +35,8 @@
 #include "ksession.h"
 #include "ColorScheme.h"
 
+#include "customcolorscheme.h"
+
 class QDrag;
 class QDragEnterEvent;
 class QDropEvent;
@@ -98,6 +100,8 @@ class TerminalDisplay : public QQuickPaintedItem
     Q_PROPERTY(bool selectedText READ selectedText CONSTANT)
 
     Q_PROPERTY(qreal backgroundOpacity READ backgroundOpacity WRITE setBackgroundOpacity NOTIFY backgroundOpacityChanged)
+    Q_PROPERTY(CustomColorScheme* customColorScheme READ customColorScheme CONSTANT FINAL)
+    Q_PROPERTY(bool readOnly READ readOnly WRITE setReadOnly NOTIFY readOnlyChanged)
 
 public:
     /** Constructs a new terminal display widget with the specified parent. */
@@ -289,7 +293,7 @@ public:
     /**
      * Returns the height of the characters in the font used to draw the text in the display.
      */
-    int  fontHeight()   { return _fontHeight;   }
+    Q_INVOKABLE int  fontHeight()   { return _fontHeight;   }
     /**
      * Returns the width of the characters in the display.
      * This assumes the use of a fixed-width font.
@@ -448,6 +452,9 @@ public:
     // of the character at that point.
 
     void getCharacterPosition(const QPoint& widgetPoint,int& line,int& column) const;
+    
+    void setReadOnly(bool value);
+    bool readOnly() const;
 
 public slots:
 
@@ -557,6 +564,11 @@ public slots:
     void simulateMouseRelease(int x, int y, int button, int buttons, int modifiers);
     void simulateMouseDoubleClick(int x, int y, int button, int buttons, int modifiers);
 
+    void findNext(const QString &regexp);
+    void findPrevious(const QString &regexp);
+    void matchFound(int startColumn, int startLine, int endColumn, int endLine);
+    void noMatchFound();
+    
 signals:
     void backgroundOpacityChanged();
 
@@ -620,6 +632,8 @@ signals:
     void blinkingCursorStateChanged();
     void boldIntenseChanged();
 
+    void readOnlyChanged();
+    
 protected:
     bool event(QEvent *);
 
@@ -687,6 +701,7 @@ protected slots:
 private slots:
     void swapColorTable();
     void tripleClickTimeout();  // resets possibleTripleClick
+    void applyColorScheme();
 
 private:
 
@@ -922,16 +937,26 @@ private:
     int getScrollbarMaximum();
     int getScrollbarMinimum();
 
+
     QSize getFontMetrics();
 
     void setFullCursorHeight(bool val);
 
+    CustomColorScheme* m_customColorScheme;
+   const Konsole::ColorScheme *m_scheme;
+   
+   bool m_readOnly = false;
+
 public:
     static void setTransparencyEnabled(bool enable)
     {
         HAVE_TRANSPARENCY = enable;
     }
     bool fullCursorHeight() const;
+    CustomColorScheme* customColorScheme() const
+    {
+        return m_customColorScheme;
+    }
 };
 
 }
